@@ -39,9 +39,9 @@ def mapping_get(uri, mapping):
             return v
     # 3. try to match local names with * prefix
     # try to match longest first, so sort the mapping by key length
-    l = list(mapping.items())
-    l.sort(key=lambda i: len(i[0]), reverse=True)
-    for k, v in l:
+    lst = list(mapping.items())
+    lst.sort(key=lambda i: len(i[0]), reverse=True)
+    for k, v in lst:
         if k[0] == '*' and ln.endswith(k[1:]):
             return v
     raise KeyError(uri)
@@ -54,7 +54,7 @@ def mapping_match(uri, mapping):
 
     """
     try:
-        val = mapping_get(uri, mapping)
+        _ = mapping_get(uri, mapping)
         return True
     except KeyError:
         return False
@@ -64,8 +64,8 @@ def in_general_ns(uri):
     """Return True iff the URI is in a well-known general RDF namespace.
 
     URI namespaces considered well-known are RDF, RDFS, OWL, SKOS and DC."""
-    RDFuri = RDF.uri
-    RDFSuri = RDFS.uri
+    RDFuri = str(RDF)
+    RDFSuri = str(RDFS)
 
     for ns in (RDFuri, RDFSuri, OWL, SKOS, DC):
         if uri.startswith(str(ns)):
@@ -79,24 +79,18 @@ def get_concept_scheme(rdf):
     Returns None if no skos:ConceptScheme is present.
     """
     # add explicit type
-    for s, o in rdf.subject_objects(SKOS.inScheme):
+    for s, o in sorted(rdf.subject_objects(SKOS.inScheme)):
         if not isinstance(o, Literal):
             rdf.add((o, RDF.type, SKOS.ConceptScheme))
         else:
             logging.warning(
                 "Literal value %s for skos:inScheme detected, ignoring.", o)
-    css = list(rdf.subjects(RDF.type, SKOS.ConceptScheme))
+    css = sorted(rdf.subjects(RDF.type, SKOS.ConceptScheme))
+    cs = next(iter(css), None)
     if len(css) > 1:
-        css.sort()
-        cs = css[0]
         logging.warning(
             "Multiple concept schemes found. "
             "Selecting %s as default concept scheme.", cs)
-    elif len(css) == 1:
-        cs = css[0]
-    else:
-        cs = None
-
     return cs
 
 
@@ -135,24 +129,20 @@ def create_concept_scheme(rdf, ns, lname=''):
     ont = None
     if not ns:
         # see if there's an owl:Ontology and use that to determine namespace
-        onts = list(rdf.subjects(RDF.type, OWL.Ontology))
+        onts = sorted(rdf.subjects(RDF.type, OWL.Ontology))
+        ont = next(iter(onts), None)
+
         if len(onts) > 1:
-            onts.sort()
-            ont = onts[0]
             logging.warning(
                 "Multiple owl:Ontology instances found. "
                 "Creating concept scheme from %s.", ont)
-        elif len(onts) == 1:
-            ont = onts[0]
-        else:
-            ont = None
 
         if not ont:
             logging.info(
                 "No skos:ConceptScheme or owl:Ontology found. "
                 "Using namespace auto-detection for creating concept scheme.")
             ns = detect_namespace(rdf)
-        elif ont.endswith('/') or ont.endswith('#') or ont.endswith(':'):
+        elif ont[-1:] in ['/', '#', ':']:
             ns = ont
         else:
             ns = ont + '/'
@@ -211,7 +201,7 @@ def transform_sparql_update(rdf, update_query):
     logging.debug("performing SPARQL Update transformation")
 
     if update_query[0] == '@':  # actual query should be read from file
-        update_query = file(update_query[1:]).read()
+        update_query = open(update_query[1:]).read()
 
     logging.debug("update query: %s", update_query)
     rdf.update(update_query)
@@ -223,7 +213,7 @@ def transform_sparql_construct(rdf, construct_query):
     logging.debug("performing SPARQL CONSTRUCT transformation")
 
     if construct_query[0] == '@':  # actual query should be read from file
-        construct_query = file(construct_query[1:]).read()
+        construct_query = open(construct_query[1:]).read()
 
     logging.debug("CONSTRUCT query: %s", construct_query)
 
@@ -244,7 +234,7 @@ def transform_concepts(rdf, typemap):
             continue
         types.add(o)
 
-    for t in types:
+    for t in sorted(types):
         if mapping_match(t, typemap):
             newval = mapping_get(t, typemap)
             newuris = [v[0] for v in newval]
@@ -273,7 +263,7 @@ def transform_literals(rdf, literalmap):
                    and (p in literalmap or not in_general_ns(p)):
                     props.add(p)
 
-    for p in props:
+    for p in sorted(props):
         if mapping_match(p, literalmap):
             newval = mapping_get(p, literalmap)
             newuris = [v[0] for v in newval]
@@ -298,7 +288,7 @@ def transform_relations(rdf, relationmap):
                    and (p in relationmap or not in_general_ns(p)):
                     props.add(p)
 
-    for p in props:
+    for p in sorted(props):
         if mapping_match(p, relationmap):
             newval = mapping_get(p, relationmap)
             logging.debug("transform relation %s -> %s", p, str(newval))
@@ -583,7 +573,7 @@ def cleanup_classes(rdf):
        unused classes. If a class is also a skos:Concept or skos:Collection,
        remove the 'classness' of it but leave the Concept/Collection."""
     for t in (OWL.Class, RDFS.Class):
-        for cl in rdf.subjects(RDF.type, t):
+        for cl in sorted(rdf.subjects(RDF.type, t)):
             # SKOS classes may be safely removed
             if cl.startswith(str(SKOS)):
                 logging.debug("removing SKOS class definition: %s", cl)
@@ -615,12 +605,12 @@ def cleanup_classes(rdf):
 def cleanup_properties(rdf):
     """Remove unnecessary property definitions.
 
-    Reemoves SKOS and DC property definitions and definitions of unused
+    Removes SKOS and DC property definitions and definitions of unused
     properties."""
     for t in (RDF.Property, OWL.DatatypeProperty, OWL.ObjectProperty,
               OWL.SymmetricProperty, OWL.TransitiveProperty,
               OWL.InverseFunctionalProperty, OWL.FunctionalProperty):
-        for prop in rdf.subjects(RDF.type, t):
+        for prop in sorted(rdf.subjects(RDF.type, t)):
             if prop.startswith(str(SKOS)):
                 logging.debug(
                     "removing SKOS property definition: %s", prop)
@@ -758,7 +748,7 @@ def skosify(*sources, **config):
     logging.debug("Phase 1: Parsing input files")
     try:
         voc = read_rdf(sources, config.from_format)
-    except:
+    except Exception:
         logging.critical("Parsing failed. Exception: %s",
                          str(sys.exc_info()[1]))
         sys.exit(1)
@@ -833,6 +823,10 @@ def skosify(*sources, **config):
     # check for duplicate labels
     check_labels(voc, config.preflabel_policy)
 
+    logging.debug("Phase 10: Performing post update query")
+    if config.post_update_query is not None:
+        transform_sparql_update(voc, config.post_update_query)
+
     processtime = time.time()
 
     logging.debug("reading input file took  %d seconds",
@@ -840,6 +834,6 @@ def skosify(*sources, **config):
     logging.debug("processing took          %d seconds",
                   (processtime - inputtime))
 
-    logging.debug("Phase 10: Writing output")
+    logging.debug("Phase 11: Writing output")
 
     return voc
